@@ -1,6 +1,6 @@
 /*
 parolottero
-Copyright (C) 2021-2022 Salvo "LtWorf" Tomaselli
+Copyright (C) 2021-2024 Salvo "LtWorf" Tomaselli
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as
@@ -23,17 +23,15 @@ author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 #include <QObject>
 #include <QString>
-#include <QSet>
 #include <QFile>
-#include <QMap>
-#include <QList>
 #include <QStringList>
+#include <QMap>
 
 class Language : public QObject
 {
     Q_OBJECT
 public:
-    explicit Language(QFile &langfile, QFile &wordlist, QObject *parent = nullptr);
+    explicit Language(QFile &langfile, QObject *parent = nullptr);
     QStringList letters;
     QStringList vowels;
     QString name;
@@ -41,14 +39,16 @@ public:
 public slots:
     bool is_word(QString word);
     int get_score(QString letter);
-    QStringList get_long_words();
+    QStringList get_long_words(unsigned int* seed);
+    uint32_t get_version();
 
 private:
-    QSet<QString> words;
-    QStringList longwordslist;
+    QFile *file;
+    uchar* map_ptr;
+    qint64 map_size;
     QMap<QString, unsigned int> score;
-    void load_langfile(QFile &file);
-
+    void check_languagefile();
+    QString string_at_offset(uint32_t offset);
 signals:
 
 };
